package main

import (
	"log"

	"git.paulbsd.com/paulbsd/coronafana/src/config"
	"git.paulbsd.com/paulbsd/coronafana/src/coronafana"
	"git.paulbsd.com/paulbsd/coronafana/src/database"
	"git.paulbsd.com/paulbsd/coronafana/src/network"
	_ "github.com/lib/pq"
)

func main() {
	var cfg config.Config
	var cr coronafana.Coronafana
	var err error

	err = cfg.GetConfig()
	if err != nil {
		log.Fatalln(err)
	}

	err = database.InitDatabase(&cfg)
	if err != nil {
		log.Fatalln(err)
	}
	defer cfg.Db.Close()

	t, d, dc, err := network.InitTorSession()
	if err != nil {
		log.Fatalln(err)
	}
	defer dc()
	defer t.Close()

	cr, err = coronafana.GetData(cfg, d)
	if err != nil {
		log.Fatalln(err)
	}

	// Process global data
	err = coronafana.InsertData(cfg, cr.Coronaglobaldata)
	if err != nil {
		log.Println(err)
	}

	// Process pays data
	err = coronafana.InsertData(cfg, cr.Coronapaysdata)
	if err != nil {
		log.Println(err)
	}
}
