package config

import (
	"flag"

	"git.paulbsd.com/paulbsd/coronafana/utils"
	"gopkg.in/ini.v1"
	"xorm.io/xorm"
)

// GetConfig fetch configuration
func (config *Config) GetConfig() (err error) {
	var configfile string
	var debug bool

	flag.Usage = utils.Usage

	flag.StringVar(&configfile, "configfile", "coronafana.ini", "Config file to use with coronafana section")
	flag.BoolVar(&debug, "debug", false, "Set debug flag")
	flag.Parse()

	cfg, err := ini.Load(configfile)
	if err != nil {
		return
	}

	*config = Config{
		Debug:      debug,
		Diffdays:   2,
		DbHostname: "localhost",
		DbName:     "database",
		DbUsername: "username",
		DbPassword: "password",
		DbTable:    "corona",
		CoronaURL:  "https://coronavirus.politologue.com/data/coronavirus/coronacsv.aspx?format=json",
	}

	err = cfg.Section("coronafana").MapTo(config)
	if err != nil {
		return
	}

	return
}

// Config is the global config of g2g
type Config struct {
	CoronaURL       string
	Db              *xorm.Engine
	Debug           bool
	Diffdays        int    `ini:"diffdays"`
	DbHostname      string `ini:"db_hostname"`
	DbName          string `ini:"db_name"`
	DbUsername      string `ini:"db_username"`
	DbPassword      string `ini:"db_password"`
	DbTable         string `ini:"db_table"`
	DbMaxDateGlobal string
	DbMaxDatePays   string
}
